@@ -50,6 +50,12 @@ class CallStacks(object):
         cls.current_contract.add_statement(s)
         return s.node_id()
 
+    @classmethod
+    def break_(cls):
+        # TODO: Add when FunC supports or we move to TVM Engine
+        # cls.add_statement(Statement.BREAK)
+        raise Exception("FunC doesn't support break keyword!")
+
     @classmethod
     def return_(cls, entity):
         ReferenceTable.mark(entity)
