@@ -1,9 +1,9 @@
+import subprocess
 from os.path import join as pjoin
 
 import click
 
 from rift.cli.entry import entry
-import subprocess
 
 templates = {
     "bare": "https://github.com/sky-ring/rift-bare-template",
@@ -30,7 +30,11 @@ def init(name, path, base):
     click.echo(f"Getting template {base_n} from {repo_n}")
 
     pt = pjoin(path, name)
-    p = subprocess.run(["git", "clone", repo, pt], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    p = subprocess.run(
+        ["git", "clone", repo, pt],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
     if p.returncode == 0:
         click.echo(click.style("Successfully created project!", fg="green"))
     else:
