@@ -1,2 +1,2 @@
 from rift.network.account import Account, AccountState
-from rift.network.network import Network
+from rift.network.v2_network import Network
